@@ -1,11 +1,11 @@
 package UUID::Random;
 
-use 5.008008;
+require 5.006_001;
 use strict;
 use warnings;
 
 
-our $VERSION = '0.02';
+our $VERSION = '0.04';
 
 sub generate {
   my @chars = ('a'..'f',0..9);
